class ErrorHandler:
    def __init__(self, config):
        self.config = config

    def handle_error(self, context, handler, exception):
        pass
